# Eeterm -- Terminal for Eemyle
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2003-2019 Easter-eggs
# https://gitlab.easter-eggs.com/ee/eeterm
#
# This file is part of Eeterm.
#
# Eeterm is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Eeterm is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Eeterm -- Terminal for Eemyle"""

import logging
import os
import tempfile

import gi
from eessh.client import EeSSHClient
from eessh.config import config as eessh_config

from eeterm.config import config as eeterm_config

log = logging.getLogger(__name__)


def main(argv=None):
    """Eeterm entrypoint"""

    # Parse argument
    eeterm_config.add_child(eessh_config)
    eeterm_config.parse_arguments_options(argv)

    # Disable cache
    # Note: do not import module before to avoid putting its config parameters in configuration
    # file and remove its config section for same reason.
    import eessh.cache  # pylint: disable=import-outside-toplevel

    eessh.cache.disable()
    eessh_config.remove_section("cache")

    # Set instance CTRL/DATA fifo filepaths
    pid = os.getpid()

    EeSSHClient.CTRL_FIFO = tempfile.mkstemp(prefix=f"eeterm-{pid}-", suffix="-ctrl")
    EeSSHClient.DATA_FIFO = tempfile.mkstemp(prefix=f"eeterm-{pid}-", suffix="-data")

    # Gtk initialization
    gi.require_version("Gdk", "3.0")
    gi.require_version("Gtk", "3.0")
    gi.require_version("Vte", "2.91")

    # Launch application
    # Note: can't import it before to avoid importing gi stuff before setting required version
    from eeterm.core import Application  # pylint: disable=import-outside-toplevel

    app = Application()
    app.run()
