# Eeterm -- Terminal for Eemyle
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2003-2019 Easter-eggs
# https://gitlab.easter-eggs.com/ee/eeterm
#
# This file is part of Eeterm.
#
# Eeterm is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Eeterm is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Configuration stuff"""

from eessh.config import BooleanOption, Config, IntegerOption, StringOption

from eeterm.const import APPNAME, DEFAULT_CONFIG_FILENAME, VERSION

# Initialize config object
config = Config(APPNAME, version=VERSION, default_filename=DEFAULT_CONFIG_FILENAME)


global_section = config.add_section("global", comment="Global", order=1)
global_section.add_option(StringOption, "tab_position", default="top")


term_section = config.add_section("terminal", comment="Terminal", order=2)

# General
term_section.add_option(
    BooleanOption,
    "use_system_font",
    default=False,
    comment="Use system font",
    arg_help="Use system font",
)
term_section.add_option(
    StringOption,
    "font",
    default="Monospace 10",
    comment="Custom font to use",
    arg_help="Custom font to use",
)
term_section.add_option(BooleanOption, "audible_bell", default=False)
term_section.add_option(BooleanOption, "allow_bold", default=True)
term_section.add_option(StringOption, "cursor_blink_mode", default="on")
term_section.add_option(BooleanOption, "mouse_autohide", default=True)
term_section.add_option(StringOption, "word_char_exceptions", default="-A-Za-z0-9,./?%&#@~_")

# Colors
term_section.add_option(StringOption, "color_scheme", default="system")
term_section.add_option(StringOption, "background", default="#000000")
term_section.add_option(StringOption, "foreground", default="#FFFFFF")
term_section.add_option(StringOption, "color_bold", default="#FFFFFF")
term_section.add_option(StringOption, "palette_scheme", default="system")
# Custom palette (default is linux)
term_section.add_option(StringOption, "palette_0", default="#000000")
term_section.add_option(StringOption, "palette_1", default="#A80000")
term_section.add_option(StringOption, "palette_2", default="#00A800")
term_section.add_option(StringOption, "palette_3", default="#A85400")
term_section.add_option(StringOption, "palette_4", default="#0000A8")
term_section.add_option(StringOption, "palette_5", default="#A800A8")
term_section.add_option(StringOption, "palette_6", default="#00A8A8")
term_section.add_option(StringOption, "palette_7", default="#A8A8A8")
term_section.add_option(StringOption, "palette_8", default="#545454")
term_section.add_option(StringOption, "palette_9", default="#FF5454")
term_section.add_option(StringOption, "palette_10", default="#54FF54")
term_section.add_option(StringOption, "palette_11", default="#FFFF54")
term_section.add_option(StringOption, "palette_12", default="#5454FF")
term_section.add_option(StringOption, "palette_13", default="#FF54FF")
term_section.add_option(StringOption, "palette_14", default="#54FFFF")
term_section.add_option(StringOption, "palette_15", default="#FFFFFF")

# Scrolling
term_section.add_option(IntegerOption, "scrollback_lines", default=1000)
term_section.add_option(BooleanOption, "scroll_on_output", default=True)
term_section.add_option(BooleanOption, "scroll_on_keystroke", default=True)
term_section.add_option(IntegerOption, "scroll_step_increment", default=3)
term_section.add_option(IntegerOption, "scroll_page_increment", default=10)

# Compatibility
term_section.add_option(StringOption, "backspace_binding", default="auto")
term_section.add_option(StringOption, "delete_binding", default="auto")

# Shell
term_section.add_option(StringOption, "prefered_shell", default="/bin/bash -l")
